summaryrefslogtreecommitdiffstats
path: root/kopete/plugins/smpppdcs/iconnector.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:34 -0600
commit83677e35509b4dafac63b76995652bdf3b49f209 (patch)
tree591f1dc22278addb439726c42896376b17bb42bd /kopete/plugins/smpppdcs/iconnector.h
parent808e453c56036211f57482ed847d54aca01bba68 (diff)
downloadtdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.tar.gz
tdenetwork-83677e35509b4dafac63b76995652bdf3b49f209.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 808e453c56036211f57482ed847d54aca01bba68.
Diffstat (limited to 'kopete/plugins/smpppdcs/iconnector.h')
-rw-r--r--kopete/plugins/smpppdcs/iconnector.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/plugins/smpppdcs/iconnector.h b/kopete/plugins/smpppdcs/iconnector.h
index c4846862..ab63ec71 100644
--- a/kopete/plugins/smpppdcs/iconnector.h
+++ b/kopete/plugins/smpppdcs/iconnector.h
@@ -37,9 +37,9 @@ public:
* This method needs to get reimplemented at classes which implement
* this interface.
*
* @param newStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
*/
- virtual void setConnectedStatus(bool newStatus) = 0;
+ virtual void setConnectedtqStatus(bool newtqStatus) = 0;
};
#endif
@@ -37,9 +37,9 @@ public:
* this interface.
*
- * @param newStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
+ * @param newtqStatus the status of the internet connection, <code>TRUE</code> if there is a connection, otherwise <code>FALSE</code>
*/